#[non_exhaustive]pub enum ListSessionsError {
InternalServerException(InternalServerException),
InvalidRequestException(InvalidRequestException),
ResourceNotFoundException(ResourceNotFoundException),
Unhandled(Unhandled),
}Expand description
Error type for the ListSessionsError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InternalServerException(InternalServerException)
Indicates a platform issue, which may be due to a transient condition or outage.
InvalidRequestException(InvalidRequestException)
Indicates that something is wrong with the input to the request. For example, a required parameter may be missing or out of range.
ResourceNotFoundException(ResourceNotFoundException)
A resource, such as a workgroup, was not found.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl ListSessionsError
impl ListSessionsError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the ListSessionsError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the ListSessionsError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is ListSessionsError::InternalServerException.
Sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is ListSessionsError::InvalidRequestException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is ListSessionsError::ResourceNotFoundException.