#[non_exhaustive]pub struct ListSessionsInput {
pub work_group: Option<String>,
pub state_filter: Option<SessionState>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.work_group: Option<String>The workgroup to which the session belongs.
state_filter: Option<SessionState>A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
max_results: Option<i32>The maximum number of sessions to return.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The workgroup to which the session belongs.
Sourcepub fn state_filter(&self) -> Option<&SessionState>
pub fn state_filter(&self) -> Option<&SessionState>
A filter for a specific session state. A description of each state follows.
CREATING - The session is being started, including acquiring resources.
CREATED - The session has been started.
IDLE - The session is able to accept a calculation.
BUSY - The session is processing another task and is unable to accept a calculation.
TERMINATING - The session is in the process of shutting down.
TERMINATED - The session and its resources are no longer running.
DEGRADED - The session has no healthy coordinators.
FAILED - Due to a failure, the session and its resources are no longer running.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of sessions to return.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn builder() -> ListSessionsInputBuilder
pub fn builder() -> ListSessionsInputBuilder
Creates a new builder-style object to manufacture ListSessionsInput.