#[non_exhaustive]pub struct ListSessionsOutput {
pub next_token: Option<String>,
pub sessions: Option<Vec<SessionSummary>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
sessions: Option<Vec<SessionSummary>>A list of sessions.
Implementations
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn sessions(&self) -> &[SessionSummary]
pub fn sessions(&self) -> &[SessionSummary]
A list of sessions.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sessions.is_none().
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn builder() -> ListSessionsOutputBuilder
pub fn builder() -> ListSessionsOutputBuilder
Creates a new builder-style object to manufacture ListSessionsOutput.